Python: module util

util | index /tmp/makerelease-pwman-python.te7lW1kN/pwman-python-2.4/libpwman/util.py

`# Simple password manager
# Copyright (c) 2011-2019 Michael Buesch <m@bues.ch>
# Licensed under the GNU/GPL version 2 or later.`

Modules
`` |  |
curses | getpass | os | sys

Functions
`` |  | clearScreen() readPassphrase(prompt, verify=False) stdout(text, flush=True) uniq(l, sort=True)

Data
`` |  | __all__ = ['osIsWindows', 'osIsPosix', 'uniq', 'stdout', 'clearScreen', 'readPassphrase'] osIsPosix = True osIsWindows = False